@@ -29,31 +29,29 @@
 #' @export
 #'
 #' @examples
-#' library(raster)
-#'
 #' coords <- rbind(c(-100, -90), c(80, 90), c(80, 0), c(40, -40))
 #' crs <- sp::CRS("+init=epsg:4326")
 #' transect <- sp::SpatialPoints(coords, proj4string = crs)
-#' r <- raster(nrows = 10, ncols = 10, ymn = -80, ymx = 80, crs = crs)
+#' r <- raster::raster(nrows = 10, ncols = 10, ymn = -80, ymx = 80, crs = crs)
 #' names(r) <- "value"
 #' set.seed(0)
-#' r[] <- runif(ncell(r))
+#' r[] <- runif(raster::ncell(r))
 #' r[4, 6] <- NA
-#' plot(r, xlab = "x", ylab = "y")
-#' lines(SpatialLines(list(sp::Lines(list(sp::Line(coords)), ID = "Transect")), proj4string = crs))
+#' PlotMap(r)
+#' l <- sp::Lines(list(sp::Line(coords)), ID = "Transect")
+#' lines(sp::SpatialLines(list(l), proj4string = crs))
 #' points(transect, pch = 21, bg = "red")
 #' segs <- ExtractAlongTransect(transect, r)
-#' for (i in 1:length(segs)) points(segs[[i]], col = "blue")
+#' for (i in seq_along(segs)) points(segs[[i]])
 #'
 #' dev.new()
 #' xlab <- "Distance along transect"
 #' ylab <- "Raster value"
-#' xlim <- range(vapply(segs, function(seg) range(seg@data[, "dist"]), c(0, 0)))
-#' ylim <- range(vapply(segs, function(seg) range(seg@data[, "value"], na.rm = TRUE),
-#'                      c(0, 0)))
+#' xlim <- range(vapply(segs, function(i) range(i@data[, "dist"]), c(0, 0)))
+#' ylim <- range(vapply(segs, function(i) range(i@data[, "value"], na.rm = TRUE), c(0, 0)))
 #' plot(NA, type = "n", xlab = xlab, ylab = ylab, xlim = xlim, ylim = ylim)
-#' for (i in 1:length(segs))
-#'   lines(segs[[i]]@data[, c("dist", "value")], col = rainbow(length(segs))[i])
+#' for (i in seq_along(segs)) lines(segs[[i]]@data[, c("dist", "value")],
+#'                                  col = rainbow(length(segs))[i])
 #' coords <- sp::coordinates(transect)
 #' n <- length(transect)
 #' d <- cumsum(c(0, as.matrix(dist((coords)))[cbind(1:(n - 1), 2:n)]))
@@ -61,6 +59,8 @@
 #' mtext(paste0("(", paste(head(coords, 1), collapse = ", "), ")"), adj = 0)
 #' mtext(paste0("(", paste(tail(coords, 1), collapse = ", "), ")"), adj = 1)
 #'
+#' graphics.off()
+#'
 
 ExtractAlongTransect <- function(transect, r) {
 
@@ -72,7 +72,7 @@ ExtractAlongTransect <- function(transect, r) {
   if (inherits(transect, "SpatialLines"))
     transect <- methods::as(transect, "SpatialPoints")
 
-  crs <- sp::CRS(proj4string(r))
+  crs <- raster::crs(r)
 
   v <- sp::coordinates(sp::spTransform(transect, crs))
   if (length(v) < 2) stop("number of vertices in transect is < 2")
